<p align="center">
    <a href="https://crawfish.readthedocs.io/en/latest" target="_blank" rel="noopener noreferrer">
        <img src="https://res.cloudinary.com/dmuligbfy/image/upload/c_scale,r_25,w_150/Crawfish/crawfish.png" alt="logo">
    </a>
</p>

<h1 align="center">
Django Crawfish
</h1>
<p align="center">
    <a href=""><img src="https://img.shields.io/pypi/l/django-crawfish" alt="License"></a>
    <a href=""><img src="https://img.shields.io/pypi/v/django-crawfish" alt="PyPi"></a>
    <a href=""><img src="https://img.shields.io/gitlab/pipeline/crawfordleeds/crawfish" alt="GitLab Pipeline"></a>
    <a href=""><img src="https://img.shields.io/pypi/djversions/django-crawfish" alt="Django Versions"></a>
    <a href=""><img src="https://img.shields.io/pypi/pyversions/django-crawfish" alt="Python Versions"></a>
    <a href=""><img src="https://gitlab.com/crawfordleeds/crawfish/badges/master/pipeline.svg" alt="Pipeline"></a>

</p>

<p align="center">
    <a href="https://gitlab.com/crawfordleeds/crawfish/-/commits/master"><img src="https://gitlab.com/crawfordleeds/crawfish/badges/master/coverage.svg" alt="Coverage Report"></a>
    <a href="https://codecov.io/gl/crawfordleeds/crawfish/"><img src="https://img.shields.io/codecov/c/gl/crawfordleeds/crawfish?label=Codecov%20Coverage" alt="Codecov"></a>

</p>


This project contains a collection of code I re-use for most of my Django projects and is not [yet] well suited
for public consumption.

## Documentation

[https://crawfish.readthedocs.io/en/latest](https://crawfish.readthedocs.io/en/latest)

### Installation

```bash
pip install django-crawfish
```

## Development

Install package dependencies:

```bash
pip install -e .
```

Install dev dependencies:

```bash
pip install -e '.[dev]'
```

Run tests:

```bash
python runtests.py

```

### Building Documentation

Move to the docs directory:
```sh
cd docs/
```

Build the documentation (must have dev dependencies installed):
```sh
make html
```

